@@ -5,7 +5,7 @@ imports.gi.versions.Clutter = "0.9";
 Clutter = imports.gi.Clutter;
 GObject = imports.gi.GObject;
 
-Clutter.init(null, null);
+Clutter.init(Seed.argv);
 
 colors = [	"blanched almond", 
 		"OldLace", 
@@ -89,7 +89,7 @@ function animate_rectangles(rectangles){
 
 var stage = new Clutter.Stage();
 var rectangles = new Array(colors.length);
-stage.signal.hide.connect(function(){Clutter.main_quit();});
+stage.signal.hide.connect(Clutter.main_quit);
 
 create_rectangles(rectangles, colors);
 
