@@ -318,27 +318,100 @@ seed_make_native_closure (JSContextRef ctx,
   return privates;
 }
 
-SeedClosure *
-seed_make_gclosure (JSContextRef ctx, JSObjectRef function, JSObjectRef this)
+static void
+closure_invalidated (gpointer data, GClosure * c)
+{
+  SeedClosure *closure = (SeedClosure *) c;
+  
+  SEED_NOTE (FINALIZATION, "Finalizing closure.");
+  if (closure->user_data && !JSValueIsUndefined(eng->context, closure->user_data))
+    JSValueUnprotect(eng->context, closure->user_data);
+  if (!JSValueIsUndefined (eng->context, closure->function))
+    JSValueUnprotect (eng->context, closure->function);
+  
+  g_free (closure->description);
+
+}
+
+JSObjectRef
+seed_closure_get_callable (GClosure *c)
+{
+  return ((SeedClosure *)c)->function;
+}
+
+JSValueRef
+seed_closure_invoke (GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception)
+{
+  JSContextRef ctx = JSGlobalContextCreateInGroup (context_group, 0);
+  JSValueRef *real_args = g_newa (JSValueRef, argc +1);
+  JSValueRef ret;
+  guint i;
+  
+  seed_prepare_global_context (ctx);
+  for (i = 0; i < argc; i++)
+    real_args[i] = args[i];
+  args[argc] = ((SeedClosure *)closure)->user_data ? ((SeedClosure *)closure)->user_data : JSValueMakeNull (ctx);
+  
+  ret = JSObjectCallAsFunction (ctx, ((SeedClosure *)closure)->function, NULL, argc+1, real_args, exception);
+  JSGlobalContextRelease ((JSGlobalContextRef) ctx);
+  
+  return ret;
+}
+
+JSValueRef
+seed_closure_invoke_with_context (JSContextRef ctx, GClosure *closure, JSValueRef *args, guint argc, JSValueRef *exception)
+{
+  JSValueRef *real_args = g_newa (JSValueRef, argc +1);
+  JSValueRef ret;
+  guint i;
+  
+  for (i = 0; i < argc; i++)
+    real_args[i] = args[i];
+  args[argc] = ((SeedClosure *)closure)->user_data ? ((SeedClosure *)closure)->user_data : JSValueMakeNull (ctx);
+  
+  ret = JSObjectCallAsFunction (ctx, ((SeedClosure *)closure)->function, NULL, argc+1, real_args, exception);
+  
+  return ret;
+}
+
+GClosure *
+seed_closure_new (JSContextRef ctx, JSObjectRef function, JSObjectRef user_data, const gchar *description)
 {
   GClosure *closure;
 
   closure = g_closure_new_simple (sizeof (SeedClosure), 0);
+  g_closure_add_finalize_notifier (closure, 0, closure_invalidated);
   g_closure_set_marshal (closure, seed_signal_marshal_func);
 
-  ((SeedClosure *) closure)->function = function;
-  ((SeedClosure *) closure)->object = 0;
-  if (this && !JSValueIsNull (ctx, this))
-    {
-      JSValueProtect (ctx, this);
-      ((SeedClosure *) closure)->this = this;
-    }
-  else
-    ((SeedClosure *) closure)->this = 0;
-
   JSValueProtect (ctx, function);
+  ((SeedClosure *) closure)->function = function;
+  if (user_data && !JSValueIsNull (ctx, user_data))
+    {
+      ((SeedClosure *) closure)->user_data = user_data;
+      JSValueProtect(ctx, user_data);
+    }
+  
+  if (description)
+    ((SeedClosure *) closure)->description = g_strdup (description);
 
-  return (SeedClosure *) closure;
+  return closure;
+}
+
+void
+seed_closure_warn_exception (GClosure *c,
+			     JSContextRef ctx,
+			     JSValueRef exception)
+{
+  JSObjectRef callable = seed_closure_get_callable (c);
+  gchar *name = seed_value_to_string (ctx, 
+				      seed_object_get_property (ctx, callable, "name"),
+				      NULL);
+  gchar *mes = seed_exception_to_string (ctx, exception);
+
+  g_warning("Exception in closure (%p) for %s (handler %s). %s", c, ((SeedClosure *)c)->description, *name == '\0' ? "[anonymous]" : name, mes);
+  
+  g_free (name);
+  g_free (mes);   
 }
 
 JSClassDefinition seed_native_callback_def = {
