@@ -62,9 +62,17 @@ seed_gi_importer_handle_function (JSContextRef ctx,
 				  GIFunctionInfo *info,
 				  JSValueRef *exception)
 {
-  seed_gobject_define_property_from_function_info (ctx, (GIFunctionInfo *) info,
-						   namespace_ref, FALSE);
-  g_base_info_ref ((GIBaseInfo *) info);
+  if (strcmp(g_base_info_get_name ((GIBaseInfo *)info), "init"))
+    seed_gobject_define_property_from_function_info (ctx, (GIFunctionInfo *) info,
+						     namespace_ref, FALSE);
+  else
+    {
+      JSObjectRef init_method;
+      
+      init_method = JSObjectMake(ctx, gobject_init_method_class, 
+				 g_base_info_ref ((GIBaseInfo *)info));
+      seed_object_set_property (ctx, namespace_ref, "init", init_method);
+    }
 }
 
 /*
@@ -528,14 +536,12 @@ seed_importer_handle_native_module (JSContextRef ctx,
   
   if (!module)
     {
-      gchar *mes = g_strdup_printf ("Error loading native module at %s: %s",
-				    file_path,
-				    g_module_error());
       // Could be a better exception
       seed_make_exception (ctx, exception, "ModuleError",
-			   mes);
+			   "Error loading native module at %s: %s",
+			   file_path,
+			   g_module_error());
       g_free (file_path);
-      g_free (mes);
       
       return NULL;
     }
@@ -620,7 +626,7 @@ seed_importer_handle_file (JSContextRef ctx,
   g_hash_table_insert (file_imports, canonical, global);
   g_free (file_path);
 
-  JSEvaluateScript (nctx, file_contents, c_global, file_name, 0, exception);
+  JSEvaluateScript (nctx, file_contents, NULL, file_name, 0, exception);
 
   // Does leak...but it's a debug statement.
   SEED_NOTE (IMPORTER, "Evaluated file, exception: %s", 
@@ -641,7 +647,7 @@ seed_importer_search (JSContextRef ctx,
 		      JSValueRef *exception)
 {
   GSList *path, *walk;
-  gchar *prop_as_lib = g_strconcat ("lib", prop, NULL);
+  gchar *prop_as_lib = g_strconcat ("lib", prop, ".", G_MODULE_SUFFIX, NULL);
   
   path = seed_importer_get_search_path (ctx, exception);
   
@@ -683,7 +689,7 @@ seed_importer_search (JSContextRef ctx,
 
 	      return ret;
 	    }
-	  else if (g_str_has_prefix (mentry, prop_as_lib) && g_str_has_suffix (entry, G_MODULE_SUFFIX))
+	  else if (!strcmp(entry, prop_as_lib))
 	    {
 	      JSObjectRef ret;
 	      
