@@ -1,6 +1,8 @@
-#!/usr/local/bin/seed
+#!/usr/bin/env seed
+
 Seed.import_namespace("Multiprocessing");
 Seed.import_namespace("Gtk");
+
 pipes = new Multiprocessing.Pipe();
 child_pid = Seed.fork();
 
@@ -10,12 +12,15 @@ if (child_pid == 0)
 	mine.add_watch(1, 
 				   function()
 				   {
-					   Seed.print("Child Got: " + mine.read());
-					   mine.write("Pong");
+					   var message = {type: "PING",
+									  data: "Hello!"};
+					   mine.write(JSON.stringify(message));
 					   return true;
 				   });
-	Gtk.main();									
+	Gtk.main();
 }
+
 mine = pipes[1];
 mine.write("Ping");
-Seed.print("Parent Got: " + mine.read());
\ No newline at end of file
+message = JSON.parse(mine.read());
+Seed.print("Parent Got: " + message.type + ": " + message.data);
