@@ -7,7 +7,7 @@
 Gtk = imports.gi.Gtk;
 GLib = imports.gi.GLib;
 
-Gtk.init(null, null);
+Gtk.init(Seed.argv);
 window = new Gtk.Window({title: "JSON Win!"});
 window.show_all();
 
